@@ -138,10 +138,10 @@ pub const NONE: DataType = DataKind::None as usize;
 pub const BINARY: DataType = DataKind::Binary as usize + (16 << KBITS);
 pub const STRING: DataType = DataKind::String as usize + (16 << KBITS);
 pub const BIGSTR: DataType = DataKind::String as usize + (250 << KBITS);
-pub const BIGINT: DataType = DataKind::Int as usize + (8 << KBITS);
-pub const INT: DataType = DataKind::Int as usize + (4 << KBITS);
-pub const SMALLINT: DataType = DataKind::Int as usize + (2 << KBITS);
-pub const TINYINT: DataType = DataKind::Int as usize + (1 << KBITS);
+pub const INT: DataType = DataKind::Int as usize + (8 << KBITS);
+pub const INT4: DataType = DataKind::Int as usize + (4 << KBITS);
+pub const INT2: DataType = DataKind::Int as usize + (2 << KBITS);
+pub const INT1: DataType = DataKind::Int as usize + (1 << KBITS);
 pub const FLOAT: DataType = DataKind::Float as usize + (4 << KBITS);
 pub const DOUBLE: DataType = DataKind::Float as usize + (8 << KBITS);
 pub const BOOL: DataType = DataKind::Bool as usize + (1 << KBITS);
