@@ -7,14 +7,17 @@
 //!
 //!# Examples
 //! ```
-//!use rustdb::{Database, SharedPagedData, SimpleFileStorage, WebTransaction, INITSQL};
+//!use rustdb::{standard_builtins, Database, SharedPagedData, SimpleFileStorage, WebTransaction, INITSQL, BuiltinMap};
 //!use std::net::TcpListener;
 //!use std::sync::Arc;
 //!
 //!    let sfs = Box::new(SimpleFileStorage::new( "..\\test.rustdb" ));
 //!    let spd = Arc::new(SharedPagedData::new(sfs));
 //!    let apd = spd.open_write();
-//!    let db = Database::new(apd, INITSQL);
+//!    let mut bmap = BuiltinMap::new();
+//!    standard_builtins( &mut bmap );
+//!    let bmap = Arc::new(bmap);
+//!    let db = Database::new(apd, INITSQL, bmap);
 //!
 //!    let listener = TcpListener::bind("127.0.0.1:3000").unwrap();
 //!    for tcps in listener.incoming() {
@@ -61,6 +64,8 @@
 //!
 //!# ToDo List
 //!
+//! Change the way builtin registration works ( pass map in when db is constructed ).
+//!
 //! Implement string(n), binary(n) where n is number of bytes stored inline. (DONE)
 //!
 //! Also simplify tinyint, smallint, int, INT to int(1), int(2), int(4), int(8) = default. (MOSTLY DONE)
@@ -90,6 +95,7 @@ pub use crate::{
 #[cfg(feature = "builtin")]
 pub use crate::{
     builtin::check_types,
+    builtin::standard_builtins,
     compile::{c_bool, c_float, c_int, c_value},
     exec::EvalEnv,
     expr::{Block, DataKind, Expr},
@@ -141,7 +147,7 @@ mod util;
 /// [GenTransaction] ( implementation of [Transaction] ).
 pub mod gentrans;
 
-/// WebTransaction ( alternative implementation of [Transaction] with http support ).
+/// [WebTransaction] ( alternative implementation of [Transaction] with http support ).
 pub mod webtrans;
 
 /// Initial SQL
@@ -150,7 +156,7 @@ pub mod init;
 /// Backing storage for database. See also [AtomicFile].
 pub mod stg;
 
-/// Page storage and sharing.
+/// Page storage and sharing, [SharedPagedData] and [AccessPagedData]
 pub mod pstore;
 
 /// [AtomicFile]
@@ -200,7 +206,7 @@ pub mod exec;
 mod exec;
 
 #[cfg(feature = "builtin")]
-/// Expression types, result of parsing.
+/// Expression types, result of parsing. [Expr]
 pub mod expr;
 #[cfg(not(feature = "builtin"))]
 mod expr;
@@ -255,6 +261,9 @@ pub type Data = Arc<Vec<u8>>;
 /// ```Rc<Database>```
 pub type DB = Rc<Database>;
 
+/// Map that defines SQL pre-defined functions.
+pub type BuiltinMap = HashMap<String, (DataKind, CompileFunc)>;
+
 /// Database with SQL-like interface.
 pub struct Database {
     /// Page storage.
@@ -272,7 +281,7 @@ pub struct Database {
     pub schemas: RefCell<HashMap<String, i64>>,
     pub tables: RefCell<HashMap<ObjRef, TablePtr>>,
     pub functions: RefCell<HashMap<ObjRef, FunctionPtr>>,
-    pub builtins: RefCell<HashMap<String, (DataKind, CompileFunc)>>,
+    pub builtins: Arc<BuiltinMap>,
     /// Flag to reset the functions cache after save.
     pub function_reset: Cell<bool>,
     /// Last id generated by INSERT.
@@ -280,9 +289,10 @@ pub struct Database {
     /// Has there been an error since last save?
     pub err: Cell<bool>,
 }
+
 impl Database {
     /// Construct a new DB, based on the specified file.
-    pub fn new(file: AccessPagedData, initsql: &str) -> DB {
+    pub fn new(file: AccessPagedData, initsql: &str, builtins: Arc<BuiltinMap>) -> DB {
         let mut dq = DummyTransaction {};
         let is_new = file.is_new();
         let mut tb = TableBuilder::new();
@@ -324,7 +334,7 @@ impl Database {
             schemas: newmap(),
             functions: newmap(),
             tables: newmap(),
-            builtins: newmap(),
+            builtins,
             function_reset: Cell::new(false),
             lastid: Cell::new(0),
             err: Cell::new(false),
@@ -363,26 +373,9 @@ GO
             db.run(initsql, &mut dq);
             db.save();
         }
-        builtin::register_builtins(&db);
         db
     }
 
-    #[cfg(feature = "builtin")]
-    /// Register a builtin function.
-    pub fn register(self: &DB, name: &str, typ: DataKind, cf: CompileFunc) {
-        self.builtins
-            .borrow_mut()
-            .insert(name.to_string(), (typ, cf));
-    }
-
-    #[cfg(not(feature = "builtin"))]
-    /// Register a builtin function.
-    fn register(self: &DB, name: &str, typ: DataKind, cf: CompileFunc) {
-        self.builtins
-            .borrow_mut()
-            .insert(name.to_string(), (typ, cf));
-    }
-
     /// Run a batch of SQL.
     pub fn run(self: &DB, source: &str, tr: &mut dyn Transaction) {
         if let Some(e) = self.go(source, tr) {
